@@ -4,13 +4,11 @@ use {
     crate::*,
     anyhow::*,
     cli_log::*,
-    std::{
-        path::{Path, PathBuf},
-    },
+    std::path::PathBuf,
 };
 
-fn print_analysis(path: &Path, args: &args::Args) -> Result<()> {
-    let mut log_base = time!("LogBase::new", LogBase::new(path, args))?;
+fn print_analysis(paths: &[PathBuf], args: &args::Args) -> Result<()> {
+    let mut log_base = time!("LogBase::new", LogBase::new(paths, args))?;
     let printer = md::Printer::new(args, &log_base);
     let base = &mut log_base;
     let trend_computer = time!("Trend computer initialization", TrendComputer::new(base, args))?;
@@ -26,11 +24,14 @@ pub fn run() -> anyhow::Result<()> {
         println!("rhit {}", env!("CARGO_PKG_VERSION"));
         return Ok(());
     }
-    let path = args.file.clone().unwrap_or_else(|| PathBuf::from("/var/log/nginx"));
+    let mut paths = args.files.clone();
+    if paths.is_empty() {
+        paths.push(PathBuf::from("/var/log/nginx"));
+    }
     if args.lines {
-        print_lines(&path, &args)?;
+        print_lines(&paths, &args)?;
     } else {
-        print_analysis(&path, &args)?;
+        print_analysis(&paths, &args)?;
     }
     log_mem(Level::Info);
     Ok(())
